==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b> é fortemente aconselhável selecionar uma palavra-chave deste grupo.',
	'avis_doublon_mot_cle' => 'Já existe uma palavra-chave com esse título. Quer criá-la mesmo assim?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administradores do site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redatores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'os visitantes do site público desde que eles postem uma mensagem num fórum.',

	// C
	'creer_et_associer_un_mot' => 'Criar e vincular uma palavra-chave',

	// I
	'icone_creation_groupe_mots' => 'Criar um novo grupo de palavras',
	'icone_creation_mots_cles' => 'Criar uma nova palavra-chave',
	'icone_modif_groupe_mots' => 'Editar este grupo de palavras',
	'icone_modifier_mot' => 'Editar esta palavra-chave',
	'icone_mots_cles' => 'Palavras-chave',
	'icone_supprimer_groupe_mots' => 'Remover este grupo',
	'icone_voir_groupe_mots' => 'Exibir este grupo de palavras-chave',
	'icone_voir_tous_mots_cles' => 'Ver todas as palavras-chave',
	'info_1_groupe_mots' => '1 grupo de palavras-chave',
	'info_articles_lies_mot' => 'As matérias associadas a esta palavra-chave',
	'info_aucun_groupe_mots' => 'Nenhum grupo de palavras-chave',
	'info_aucun_mot_cle' => 'Nenhuma palavra-chave',
	'info_changer_nom_groupe' => 'Mudar o nome deste grupo:',
	'info_creation_mots_cles' => 'Crie e configure aqui as palavras-chave do site',
	'info_dans_groupe' => 'No grupo:',
	'info_delet_mots_cles' => 'Você pediu a exclusão da palavra-chave <b>@titre_mot@</b> (@type_mot@). Esta palavra-chave está vinculada a <b>@texte_lie@</b>; você precisa confirmar esta decisão:',
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Editar a palavra-chave:',
	'info_mots_cles' => 'As palavras-chave',
	'info_mots_cles_association' => 'As palavras-chave deste grupo podem ser associadas a:',
	'info_nb_groupe_mots' => '@nb@ grupos de palavras-chave',
	'info_oui_suppression_mot_cle' => 'Eu quero excluir definitivamente esta palavra-chave.',
	'info_question_mots_cles' => 'Deseja utilizar palavras-chave no seu site?',
	'info_qui_attribue_mot_cle' => 'As palavras-chave deste grupo podem ser atribuídas por:',
	'info_remplacer_mot' => 'Substituir "@titre@"',
	'info_retirer_mot' => 'Retirar esta palavra-chave',
	'info_retirer_mots' => 'Retirar todas as palavras-chave',
	'info_rubriques_liees_mot' => 'As seções ligadas a esta palavra-chave',
	'info_selection_un_seul_mot_cle' => 'Só se pode selecionar <b>uma unica</b> palavra-chave de  cada vêz neste grupo.',
	'info_supprimer_mot' => 'excluir esta palavra-chave',
	'info_titre_mot_cle' => 'Nome ou título da palavra-chave',
	'info_un_mot' => 'Um palavra-chave de cada vêz',
	'item_ajout_mots_cles' => 'Autorizar a associação de palavras-chave nos fóruns',
	'item_non_ajout_mots_cles' => 'Impedir a utilização das palavras-chaves nos fóruns',
	'item_non_utiliser_config_groupe_mots_cles' => 'Não utilizar a configuração avançada dos grupos de palavras-chave',
	'item_non_utiliser_mots_cles' => 'Não utilizar as palavras-chave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar a configuração avançada dos grupos de palavras-chave',
	'item_utiliser_mots_cles' => 'Utilizar as palavras-chave',

	// L
	'lien_ajouter_mot' => 'Incluir esta palavra-chave',
	'logo_groupe' => 'ÍCONE DESTE GRUPO',
	'logo_mot_cle' => 'ÍCONE DA PALAVRA-CHAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Você deseja ativar a configuração avançada das palavras-chave, indicando, por exemplo, que se pode selecionar uma única palavra-chave por grupo, ou que um grupo é importante...?',
	'texte_mots_cles' => 'As palavras-chave permitem criar links temáticos entre as suas matérias, independentemente de sua localização nas seções. Você poderá dessa forma enriquecer a navegação do seu site, utilizando essas propriedades para personalizar a apresentação das matérias nos seus templates.',
	'texte_mots_cles_dans_forum' => 'Você deseja permitir a utilização de palavras-chave, selecionáveis pelos visitantes, nos fóruns do site público? (Atenção: esta opção é relativamente complexa de se utilizar corretamente.)',
	'texte_nouveau_mot' => 'Nova palavra-chave',
	'titre_config_groupe_mots_cles' => 'Configuração dos grupos de palavras-chave',
	'titre_gauche_mots_edit' => 'PALAVRA-CHAVE NÚMERO:',
	'titre_groupe_mots' => 'GRUPO DE PALAVRAS-CHAVE:',
	'titre_groupe_mots_numero' => 'GRUPO DE PALAVRAS-CHAVE NÚMERO:',
	'titre_groupes_mots' => 'Grupos de palavras-chave',
	'titre_mots_cles_dans_forum' => 'Palavras-chave nos fóruns do site público',
	'titre_mots_tous' => 'As palavras-chave',
	'titre_nouveau_groupe' => 'Novo grupo',
	'titre_objets_lies_mot' => 'Vinculadas a esta palavra-chave:',
	'titre_page_mots_tous' => 'Palavras-chave'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b> é fortemente aconselhável selecionar uma palavra-chave deste grupo.',
	'avis_doublon_mot_cle' => 'Já existe uma palavra-chave com esse título. Quer criá-la mesmo assim?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administradores do site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redatores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'os visitantes do site público desde que eles postem uma mensagem num fórum.',

	// C
	'creer_et_associer_un_mot' => 'Criar e vincular uma palavra-chave',

	// I
	'icone_creation_groupe_mots' => 'Criar um novo grupo de palavras',
	'icone_creation_mots_cles' => 'Criar uma nova palavra-chave',
	'icone_modif_groupe_mots' => 'Editar este grupo de palavras',
	'icone_modifier_mot' => 'Editar esta palavra-chave',
	'icone_mots_cles' => 'Palavras-chave',
	'icone_supprimer_groupe_mots' => 'Remover este grupo',
	'icone_voir_groupe_mots' => 'Exibir este grupo de palavras-chave',
	'icone_voir_tous_mots_cles' => 'Ver todas as palavras-chave',
	'info_1_groupe_mots' => '1 grupo de palavras-chave',
	'info_articles_lies_mot' => 'As matérias associadas a esta palavra-chave',
	'info_aucun_groupe_mots' => 'Nenhum grupo de palavras-chave',
	'info_aucun_mot_cle' => 'Nenhuma palavra-chave',
	'info_changer_nom_groupe' => 'Mudar o nome deste grupo:',
	'info_creation_mots_cles' => 'Crie e configure aqui as palavras-chave do site',
	'info_dans_groupe' => 'No grupo:',
	'info_delet_mots_cles' => 'Você pediu a exclusão da palavra-chave <b>@titre_mot@</b> (@type_mot@). Esta palavra-chave está vinculada a <b>@texte_lie@</b>; você precisa confirmar esta decisão:',
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Editar a palavra-chave:',
	'info_mots_cles' => 'As palavras-chave',
	'info_mots_cles_association' => 'As palavras-chave deste grupo podem ser associadas a:',
	'info_nb_groupe_mots' => '@nb@ grupos de palavras-chave',
	'info_oui_suppression_mot_cle' => 'Eu quero excluir definitivamente esta palavra-chave.',
	'info_question_mots_cles' => 'Deseja utilizar palavras-chave no seu site?',
	'info_qui_attribue_mot_cle' => 'As palavras-chave deste grupo podem ser atribuídas por:',
	'info_remplacer_mot' => 'Substituir "@titre@"',
	'info_retirer_mot' => 'Retirar esta palavra-chave',
	'info_retirer_mots' => 'Retirar todas as palavras-chave',
	'info_rubriques_liees_mot' => 'As seções ligadas a esta palavra-chave',
	'info_selection_un_seul_mot_cle' => 'Só se pode selecionar <b>uma unica</b> palavra-chave de  cada vêz neste grupo.',
	'info_supprimer_mot' => 'excluir esta palavra-chave',
	'info_titre_mot_cle' => 'Nome ou título da palavra-chave',
	'info_un_mot' => 'Um palavra-chave de cada vêz',
	'item_ajout_mots_cles' => 'Autorizar a associação de palavras-chave nos fóruns',
	'item_non_ajout_mots_cles' => 'Impedir a utilização das palavras-chaves nos fóruns',
	'item_non_utiliser_config_groupe_mots_cles' => 'Não utilizar a configuração avançada dos grupos de palavras-chave',
	'item_non_utiliser_mots_cles' => 'Não utilizar as palavras-chave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar a configuração avançada dos grupos de palavras-chave',
	'item_utiliser_mots_cles' => 'Utilizar as palavras-chave',

	// L
	'lien_ajouter_mot' => 'Incluir esta palavra-chave',
	'logo_groupe' => 'ÍCONE DESTE GRUPO',
	'logo_mot_cle' => 'ÍCONE DA PALAVRA-CHAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Você deseja ativar a configuração avançada das palavras-chave, indicando, por exemplo, que se pode selecionar uma única palavra-chave por grupo, ou que um grupo é importante...?',
	'texte_mots_cles' => 'As palavras-chave permitem criar links temáticos entre as suas matérias, independentemente de sua localização nas seções. Você poderá dessa forma enriquecer a navegação do seu site, utilizando essas propriedades para personalizar a apresentação das matérias nos seus templates.',
	'texte_mots_cles_dans_forum' => 'Você deseja permitir a utilização de palavras-chave, selecionáveis pelos visitantes, nos fóruns do site público? (Atenção: esta opção é relativamente complexa de se utilizar corretamente.)',
	'texte_nouveau_mot' => 'Nova palavra-chave',
	'titre_config_groupe_mots_cles' => 'Configuração dos grupos de palavras-chave',
	'titre_gauche_mots_edit' => 'PALAVRA-CHAVE NÚMERO:',
	'titre_groupe_mots' => 'GRUPO DE PALAVRAS-CHAVE:',
	'titre_groupe_mots_numero' => 'GRUPO DE PALAVRAS-CHAVE NÚMERO:',
	'titre_groupes_mots' => 'Grupos de palavras-chave',
	'titre_mots_cles_dans_forum' => 'Palavras-chave nos fóruns do site público',
	'titre_mots_tous' => 'As palavras-chave',
	'titre_nouveau_groupe' => 'Novo grupo',
	'titre_objets_lies_mot' => 'Vinculadas a esta palavra-chave:',
	'titre_page_mots_tous' => 'Palavras-chave',
];
